@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import sys
 from functools import wraps
 from typing import TYPE_CHECKING
 
@@ -13,7 +12,8 @@ from e3.error import E3Error
 logger = e3.log.getLogger("e3.anod.driver")
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Literal, TypeVar
+    from typing import Any, Literal, TypeVar
+    from collections.abc import Callable
     from e3.anod.spec import Anod
     from e3.store.backends.base import Store
     from e3.anod.sandbox import SandBox
@@ -27,7 +27,7 @@ def primitive_check() -> Callable[[F], F]:
         @wraps(func)
         def wrapper(self, *args, **kwargs):
             if not has_primitive(self.anod_instance, func.__name__):
-                raise AnodError("no primitive %s" % func.__name__)
+                raise AnodError(f"no primitive {func.__name__}")
             elif self.anod_instance.build_space is None:
                 raise AnodError(".activate() has not been called")
             return func(self, *args, **kwargs)
@@ -53,11 +53,11 @@ class AnodDriver:
 
         self.anod_instance.log = e3.log.getLogger("spec." + self.anod_instance.uid)
 
-        for e in getattr(self.anod_instance, "%s_deps" % self.anod_instance.kind, ()):
+        for e in getattr(self.anod_instance, f"{self.anod_instance.kind}_deps", ()):
             if isinstance(e, self.anod_instance.Dependency):
                 dep_class = spec_repository.load(e.name)
                 dep_instance = dep_class(
-                    qualifier=e.qualifier,
+                    qualifier=e.parsed_qualifier,
                     kind=e.kind,
                     env=e.env(self.anod_instance, BaseEnv.from_env()),
                 )
@@ -91,7 +91,7 @@ class AnodDriver:
             self.anod_instance.log.critical(err)
             raise AnodError(
                 "cannot get resource metadata from store", origin=self.anod_instance.uid
-            ).with_traceback(sys.exc_info()[2])
+            ) from err
         else:
             self.store.download_resource(
                 metadata, self.anod_instance.build_space.binary_dir
