@@ -1,6 +1,6 @@
 """Low-level file manipulation.
 
-All function here should be platform indepenent, should not involve globbing or
+All function here should be platform independent, should not involve globbing or
 logging (unless in case of unexpected failure).
 """
 
@@ -15,16 +15,19 @@ import stat
 import sys
 
 
+from pathlib import Path
 from typing import TYPE_CHECKING, overload
 
-import e3
 import e3.error
 import e3.log
 
 if TYPE_CHECKING:
     from typing import Any, Literal
     from collections.abc import Callable
-    from pathlib import Path
+
+CYGPATH_MATCH: re.Pattern[str] = re.compile(
+    "/((cygdrive/|mnt/)?(?P<drive>[a-zA-Z])/)?(?P<path>.*)", re.IGNORECASE
+)
 
 
 class OSFSError(e3.error.E3Error):
@@ -160,7 +163,7 @@ def df(path: str | Path, full: bool = False) -> int | tuple:
     if sys.platform == "win32":  # unix: no cover
         import ctypes
 
-        c_path = ctypes.c_wchar_p(path)
+        c_path = ctypes.c_wchar_p(str(path))
         GetDiskFreeSpaceEx: Callable = ctypes.WINFUNCTYPE(
             ctypes.c_int,
             ctypes.c_wchar_p,
@@ -173,13 +176,13 @@ def df(path: str | Path, full: bool = False) -> int | tuple:
             ((1, "path"), (2, "freeuserspace"), (2, "totalspace"), (2, "freespace")),
         )
 
-        def GetDiskFreeSpaceEx_errcheck(result, func, args):
+        def GetDiskFreeSpaceEx_errcheck(result, func, args):  # type: ignore[no-untyped-def]
             del func
             if not result:  # defensive code
                 raise ctypes.WinError()
-            return (args[1].value, args[2].value, args[3].value)
+            return args[1].value, args[2].value, args[3].value
 
-        GetDiskFreeSpaceEx.errcheck = GetDiskFreeSpaceEx_errcheck
+        GetDiskFreeSpaceEx.errcheck = GetDiskFreeSpaceEx_errcheck  # type: ignore[attr-defined]
         _, total, free = GetDiskFreeSpaceEx(c_path)
         used = total - free
     else:  # windows: no cover
@@ -248,6 +251,61 @@ def force_remove_file(path: str | Path) -> None:
         os.chmod(dir_path, orig_mode)
 
 
+def ldd_output_to_posix(ldd_output: str) -> str:
+    """Transform an ``ldd`` output to POSIX paths only.
+
+    This method does not have any impact when the ``ldd`` output has
+    been executed on a Unix host, because paths are already POSIX there.
+
+    It applies only to ``ldd`` outputs on Windows, where the paths starting
+    with `/c/`, `/mnt/c/` or `/cygdrive/c/` are modified to `C:/`.
+
+    For instance, ``/c/WINDOWS/System32/ntdll.dll`` is transformed to
+    ``C:/WINDOWS/System32/ntdll.dll``.
+
+    .. note:: The transformation is made on strings only to minimize the
+        call the ``cygpath``. If a file path is found, all its occurrences
+        are replaced by its POSIX value.
+
+    :param ldd_output: The output of an ``ldd`` call to transform to contain
+        only POSIX paths.
+
+    :return: An ``ldd`` output with POSIX paths only.
+    """
+    posix_content: str = ldd_output
+
+    if sys.platform == "win32":
+        transformed: dict[str, str] = {}
+        posix_path: str
+        file_path: str | None = None
+        lines: list[str] = posix_content.splitlines()
+        drive: str = Path.cwd().drive.rstrip(":")
+
+        for line in lines:
+            if line.strip().endswith(":"):
+                # Found an executable/dll path with linked dlls.
+                file_path = line.strip()[:-1]
+            elif " => " in line:
+                # Here is the list of linked dlls.
+                file_path = line.split(" => ", 1)[1].strip()
+
+            # Do not run on already transformed paths.
+            if file_path and file_path not in transformed:
+                match = CYGPATH_MATCH.match(file_path)
+                if match:
+                    # If there is no drive, replace it with current drive.
+                    posix_path = (
+                        f"{match.group('drive') or drive}:/{match.group('path')}"
+                    )
+
+                    if posix_path != file_path:
+                        # Transform all occurrences in the ldd output.
+                        posix_content = posix_content.replace(file_path, posix_path)
+                        transformed[file_path] = posix_path
+
+    return posix_content
+
+
 def max_path() -> int:
     """Return the maximum length for a path.
 
@@ -274,6 +332,29 @@ def mv(source: str | Path, target: str | Path) -> None:
         shutil.move(source, target)
 
 
+def readlink(filename: str | Path) -> str:
+    """Get target path of a symlink.
+
+    Equivalent of os.readlink with support for WSL Windows links.
+
+    :param filename: path containing a symlink
+    :return: target of the symlink
+    """
+    try:
+        return os.readlink(filename)
+    except Exception:
+        if sys.platform == "win32":
+            # This might be a WSL link
+            from e3.os.windows.fs import NTFile
+
+            reparsed_link: str | None = NTFile(filename).wsl_reparse_link_target()
+            if reparsed_link is not None:
+                return reparsed_link
+            raise
+        else:
+            raise
+
+
 def touch(filename: str | Path) -> None:
     """Update file access and modification times. Create the file if needed.
 
