@@ -83,9 +83,13 @@ def get_rlimit(platform: str | None = None) -> str:
     if platform == "x86_64-windows64":
         platform = "x86_64-windows"
 
-    from pkg_resources import resource_filename
+    import importlib.resources
 
-    return resource_filename(__name__, os.path.join("data", f"rlimit-{platform}"))
+    return str(
+        importlib.resources.files("e3.os").joinpath(
+            os.path.join("data", f"rlimit-{platform}")
+        )
+    )
 
 
 def quote_arg(arg: str) -> str:
@@ -362,8 +366,8 @@ class Run:
         self.error_file = File(error, "w")
 
         self.status: int | None = None
-        self.raw_out: bytes | None = b""
-        self.raw_err: bytes | None = b""
+        self.raw_out: bytes = b""
+        self.raw_err: bytes = b""
         self.cmds = []
 
         if env is not None:
@@ -484,25 +488,23 @@ class Run:
             self.wait()
 
     @property
-    def out(self) -> str | None:
+    def out(self) -> str:
         """Process output as string.
 
         Attempt is done to decode as utf-8 the output. If the output is not in
         utf-8 a string representation will be returned
         (see e3.text.bytes_as_str).
         """
-        return bytes_as_str(self.raw_out) if self.raw_out is not None else None
+        return bytes_as_str(self.raw_out)
 
     @property
-    def err(self) -> str | None:
+    def err(self) -> str:
         """Process error as string.
 
         Attempt is done to decode as utf-8 the output. If the output is not in
         utf-8 a string representation will be returned
         (see e3.text.bytes_as_str).
         """
-        if self.raw_err is None:
-            return None
         return bytes_as_str(self.raw_err)
 
     def command_line_image(self) -> str:
@@ -565,7 +567,10 @@ class Run:
             if isinstance(tmp_input, str):
                 tmp_input = tmp_input.encode("utf-8")
 
-            (self.raw_out, self.raw_err) = self.internal.communicate(tmp_input)
+            (raw_out, raw_err) = self.internal.communicate(tmp_input)
+            self.raw_out = raw_out if raw_out is not None else b""
+            self.raw_err = raw_err if raw_err is not None else b""
+
             self.status = self.internal.returncode
 
         self.close_files()
@@ -755,7 +760,7 @@ def wait_for_processes(process_list: list[Run], timeout: float) -> int | None:
 
                 # Wait for a sigchld signal. Note that select might
                 # be interrupted by signals thus the loop
-                select_args = [[fd_r], [], []]
+                select_args: list[list[int] | float] = [[fd_r], [], []]
                 if timeout != 0:
                     select_args.append(remain)
 
