@@ -156,6 +156,16 @@ class IOStatusBlock(Structure):
     _fields_ = [("status", NTSTATUS), ("information", POINTER(ULONG))]
 
 
+class ReparseGUIDDataBuffer(Structure):
+    _fields_ = [
+        ("tag", DWORD),
+        ("length", WORD),
+        ("reserved", WORD),
+        ("guid", DWORD),
+        ("data", ctypes.c_char * (16 * 1024)),
+    ]
+
+
 class UnicodeString(Structure):
     """Map UNICODE_STRING structure."""
 
@@ -296,7 +306,7 @@ class FileInfo:
         class_id = 6
 
     class Rename(Structure):
-        _fields_ = []  # type: list
+        _fields_ = []
         class_id = 10
 
     class Basic(Structure):
@@ -326,7 +336,7 @@ class ObjectInfo:
     """Declaration of structures returned by QueryObjectInformation."""
 
     class Name(Structure):
-        _fields_: list = []
+        _fields_ = []
         class_id = 1
 
 
@@ -384,6 +394,7 @@ class ObjectAttributes(Structure):
 class NT:
     FindFirstFile = None
     FindClose = None
+    FsControlFile = None
     Sleep = None
     GetVolumePathName = None
     SetInformationFile = None
@@ -403,6 +414,21 @@ class NT:
             kernel32 = ctypes.windll.kernel32
             ntdll = ctypes.windll.ntdll
 
+            cls.FsControlFile = ntdll.NtFsControlFile
+            cls.FsControlFile.restype = NTSTATUS
+            cls.FsControlFile.argtypes = [
+                HANDLE,
+                HANDLE,
+                LPVOID,
+                LPVOID,
+                POINTER(IOStatusBlock),
+                ULONG,
+                LPVOID,
+                ULONG,
+                POINTER(ReparseGUIDDataBuffer),
+                ULONG,
+            ]
+
             cls.FindFirstFile = kernel32.FindFirstFileW
             cls.FindFirstFile.restype = HANDLE
             cls.FindFirstFile.argtypes = [c_wchar_p, POINTER(FindData)]
